==> haskell-singleton-bool-0.1.5-6-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-singleton-bool.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 singleton-bool
version:              0.1.5
visibility:           public
id:                   singleton-bool-0.1.5-A1BUoKOE7i9KQGHsFA81g
key:                  singleton-bool-0.1.5-A1BUoKOE7i9KQGHsFA81g
license:              BSD-3-Clause
maintainer:           Oleg Grenrus <oleg.grenrus@iki.fi>
author:               Oleg Grenrus <oleg.grenrus@iki.fi>
homepage:             https://github.com/phadej/singleton-bool#readme
synopsis:             Type level booleans
description:
    Type level booleans.

    @singletons@ package provides similar functionality,
    but it has tight dependency constraints.

category:             Web
abi:                  a756337011d0d81145631fb0dd7103b0
exposed:              True
exposed-modules:      Data.Singletons.Bool
import-dirs:          /usr/lib/ghc-8.8.3/site-local/singleton-bool-0.1.5
library-dirs:         /usr/lib/ghc-8.8.3/site-local/singleton-bool-0.1.5
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.8.3/singleton-bool-0.1.5
hs-libraries:         HSsingleton-bool-0.1.5-A1BUoKOE7i9KQGHsFA81g
depends:              base-4.13.0.0 dec-0.0.3-FO6fyD2XpRyARvxKWGtzdG
haddock-interfaces:
    /usr/share/doc/haskell-singleton-bool/html/singleton-bool.haddock

haddock-html:         /usr/share/doc/haskell-singleton-bool/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-singleton-bool-0.1.5-8-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-singleton-bool.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 singleton-bool
version:              0.1.5
visibility:           public
id:                   singleton-bool-0.1.5-8peOVYGEwok6KFC3GQYpaA
key:                  singleton-bool-0.1.5-8peOVYGEwok6KFC3GQYpaA
license:              BSD-3-Clause
maintainer:           Oleg Grenrus <oleg.grenrus@iki.fi>
author:               Oleg Grenrus <oleg.grenrus@iki.fi>
homepage:             https://github.com/phadej/singleton-bool#readme
synopsis:             Type level booleans
description:
    Type level booleans.

    @singletons@ package provides similar functionality,
    but it has tight dependency constraints.

category:             Web
abi:                  13c93a406e84d8d12e985e621af2c58e
exposed:              True
exposed-modules:      Data.Singletons.Bool
import-dirs:          /usr/lib/ghc-8.10.1/site-local/singleton-bool-0.1.5
library-dirs:         /usr/lib/ghc-8.10.1/site-local/singleton-bool-0.1.5
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.1/singleton-bool-0.1.5
hs-libraries:         HSsingleton-bool-0.1.5-8peOVYGEwok6KFC3GQYpaA
depends:              base-4.14.0.0 dec-0.0.3-7CFwysk0LzzFClMA9Y5GYj
haddock-interfaces:
    /usr/share/doc/haskell-singleton-bool/html/singleton-bool.haddock

haddock-html:         /usr/share/doc/haskell-singleton-bool/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
